SeaBoxIn

Struct SeaBoxIn 

pub struct SeaBoxIn<T, A: Allocator> { /* private fields */ }
Owned, aligned pointer to a T, which is freed on Drop.

The allocator is pluggable - see Allocator.

#[repr(transparent)] such that Option<SeaBox<T>> has the same layout as *mut T.

Implementations

Source

impl<T, A: Allocator> SeaBoxIn<T, A>

pub fn new(t: T) -> Self

Available on crate feature alloc only.

Copy t into the heap.

pub fn try_new(t: T) -> Result<Self, AllocError>

pub unsafe fn try_emplace( f: impl FnOnce(&mut MaybeUninit<T>), ) -> Result<Self, AllocError>

Safety
  • Must initialize the given memory.

Note that if T is a ZST, the passed in memory is ephemeral.

pub fn unbox(self) -> T

pub const unsafe fn from_raw(ptr: *mut T) -> Self

Safety
  • Must have been allocated by A.
  • Must be a valid T.
  • This must be the only pointer to the allocation.
pub const fn into_raw(this: Self) -> *mut T